aboutsummaryrefslogtreecommitdiffstats
path: root/wiretap/libpcap.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2010-01-27 00:35:32 +0000
committerGuy Harris <guy@alum.mit.edu>2010-01-27 00:35:32 +0000
commit1c88b1f22182988d8ebe1b0a05eb4e0fec233203 (patch)
treeb8f829d5b4cd43369c2420954c58cb86d951d4a6 /wiretap/libpcap.c
parent97d3a8bb100b24d89bdb53935bc13d6c636680ef (diff)
Fix a comment.
svn path=/trunk/; revision=31693
Diffstat (limited to 'wiretap/libpcap.c')
-rw-r--r--wiretap/libpcap.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/wiretap/libpcap.c b/wiretap/libpcap.c
index e961750a8d..cdca16f234 100644
--- a/wiretap/libpcap.c
+++ b/wiretap/libpcap.c
@@ -122,8 +122,9 @@ int libpcap_open(wtap *wth, int *err, gchar **err_info)
break;
case PCAP_NSEC_MAGIC:
- /* Host that wrote it has our byte order, and was running
- a program using either standard or ss990417 libpcap. */
+ /* Host that wrote it has our byte order, and was writing
+ the file in a format similar to standard libpcap
+ except that the time stamps have nanosecond resolution. */
byte_swapped = FALSE;
modified = FALSE;
wth->tsprecision = WTAP_FILE_TSPREC_NSEC;
@@ -131,8 +132,9 @@ int libpcap_open(wtap *wth, int *err, gchar **err_info)
case PCAP_SWAPPED_NSEC_MAGIC:
/* Host that wrote it out has a byte order opposite to
- ours, and was running a program using either ss990915
- or ss991029 libpcap. */
+ ours, and was writing the file in a format similar to
+ standard libpcap except that the time stamps have
+ nanosecond resolution. */
byte_swapped = TRUE;
modified = FALSE;
wth->tsprecision = WTAP_FILE_TSPREC_NSEC;